==> nextcloud-28.0.3.tgz: nextcloud/apps/dashboard/l10n/de.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "\"{title} icon\"" : "\"{title}-Symbol\"",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Hole dir weitere Widgets aus dem App-Store",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu deinem Datenschutz werden die Wetterdaten von deinem Nextcloud-Server für dich angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Starte informiert in den Tag\n\nDas Nextcloud-Dashboard ist dein Ausgangspunkt für den Tag und gibt Dir\neinen Überblick über deine anstehenden Termine, dringende E-Mails, Chatnachrichten, eingehende Tickets, neuste Tweets und vieles mehr! Benutzer können die Widgets hinzufügen, die sie mögen und den Hintergrund nach ihren Wünschen angepassen.",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Starte informiert in den Tag\n\nDas Nextcloud Dashboard ist dein Ausgangspunkt für den Tag und gibt dir einen Überblick über deine anstehenden Termine, dringende E-Mails, Chatnachrichten, eingehende Tickets, neueste Tweets und vieles mehr! Benutzer können die gewünschten Widgets hinzufügen und den Hintergrund nach Belieben ändern."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/dashboard/l10n/de.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Starte informiert in den Tag\n\nDas Nextcloud Dashboard ist dein Ausgangspunkt für den Tag und gibt dir einen Überblick über deine anstehenden Termine, dringende E-Mails, Chatnachrichten, eingehende Tickets, neueste Tweets und vieles mehr! Benutzer können die gewünschten Widgets hinzufügen und den Hintergrund nach Belieben ändern.",
    "\"{title} icon\"" : "\"{title}-Symbol\"",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the App Store" : "Hole dir weitere Widgets aus dem App-Store",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu deinem Datenschutz werden die Wetterdaten von deinem Nextcloud-Server für dich angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Alles Gute zum Geburtstag, {name} 🥳🤩🎂🎉"
},
"nplurals=2; plural=(n != 1);");
